A library for deserializing tiled maps and tilesets made with the Tiled map editor.
Use Map::new() to loads the map using a path,
and also automatically loads any tilesets data.
see https://doc.mapeditor.org/en/stable/ for information on what the map data represents.
Note: infinite maps and templates are unsupported
Modules
- error
- Holds an enum of error types that can occur from loading tilemaps
Structs
- Colour
- Image
Layer - Layer
- Layer
Data - Map
- This is used for loading the Tiled maps and holds all of the structs in the library that describe the tilemap.
- MapMetadata
- Obj
- ObjData
- ObjGroup
- Poly
- Properties
- Text
- Tileset
- Holds information about a tileset. ie. image path, format, spacing